package com.faraphel.tasks_valider

import android.annotation.SuppressLint
import android.os.Build
import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.annotation.RequiresApi
import androidx.room.Room
import com.faraphel.tasks_valider.connectivity.bwd.BwdManager
import com.faraphel.tasks_valider.database.TaskDatabase
import com.faraphel.tasks_valider.database.populateTaskDatabaseTest
import com.faraphel.tasks_valider.ui.screen.communication.CommunicationModeSelectionScreen


class MainActivity : ComponentActivity() {
    private var bwdManager: BwdManager? = null  ///< the WiFi-Direct helper
    private lateinit var database: TaskDatabase  ///< the database manager

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)

        // Reset the database | TODO(Faraphel): only for testing purpose
        this.deleteDatabase("local")

        // Create the database
        this.database = Room.databaseBuilder(
            this,
            TaskDatabase::class.java,
            "local"
        ).build()

        // Populate the database with test data
        // TODO(Faraphel): remove test data
        Thread {
            populateTaskDatabaseTest(database)
        }.let { thread ->
            thread.start()
            thread.join()
        }

        this.setContent {
            CommunicationModeSelectionScreen(this, database)
        }
    }

    @SuppressLint("UnspecifiedRegisterReceiverFlag")
    override fun onResume() {
        super.onResume()

        // enable the WiFi-Direct events
        this.registerReceiver(this.bwdManager, BwdManager.ALL_INTENT_FILTER)
    }

    override fun onPause() {
        super.onPause()

        // disable the WiFi-Direct events
        this.unregisterReceiver(this.bwdManager)
    }
}
