package com.faraphel.tasks_valider.database.entities

import androidx.room.ColumnInfo
import androidx.room.Entity
import androidx.room.ForeignKey
import com.faraphel.tasks_valider.database.entities.base.BaseEntity
import com.google.gson.annotations.Expose


/**
 * Represent the relation that associate a subject to a person for a specific session.
 */
@Entity(
    tableName = RelationPersonSessionSubjectEntity.TABLE_NAME,
    primaryKeys = [
        "student_id",
        "session_id",
        "subject_id"
    ],
    foreignKeys = [
        ForeignKey(
            entity = PersonEntity::class,
            parentColumns = ["id"],
            childColumns = ["student_id"],
            onDelete = ForeignKey.CASCADE
        ),
        ForeignKey(
            entity = SessionEntity::class,
            parentColumns = ["id"],
            childColumns = ["session_id"],
            onDelete = ForeignKey.CASCADE
        ),
        ForeignKey(
            entity = SubjectEntity::class,
            parentColumns = ["id"],
            childColumns = ["subject_id"],
            onDelete = ForeignKey.CASCADE
        ),
    ]
)
data class RelationPersonSessionSubjectEntity (
    @ColumnInfo("student_id", index = true) @Expose val studentId: Long,
    @ColumnInfo("session_id", index = true) @Expose val sessionId: Long,
    @ColumnInfo("subject_id", index = true) @Expose val subjectId: Long,
) : BaseEntity() {
    companion object {
        const val TABLE_NAME = "relation_person_session_subject"
    }
}