package com.faraphel.tasks_valider.database

import com.faraphel.tasks_valider.connectivity.task.session.TaskRole
import com.faraphel.tasks_valider.database.entities.*

fun populateTaskDatabaseTest(database: TaskDatabase) {
    // classes
    val (
        classMiageId,
        classIsriId,
    ) = database.classDao().insert(
        ClassEntity(name="MIAGE"),
        ClassEntity(name="ISRI")
    )

    val classMiage = database.classDao().getById(classMiageId)!!
    val classIrsi = database.classDao().getById(classIsriId)!!

    // persons
    val (
        personBillyId,
        personBobbyId,
        personBettyId,
    ) = database.personDao().insert(
        PersonEntity(
            "Billy", "Bob",
            "0A1A7553-9DE5-103C-B23C-630998207116",
            "1234",
            TaskRole.STUDENT
        ),
        PersonEntity(
            "Bobby", "Bob",
            null,
            "1234",
            TaskRole.STUDENT
        ),
        PersonEntity(
            "Betty", "Bob",
            null,
            "1234",
            TaskRole.STUDENT
        )
    )

    val personBilly = database.personDao().getById(personBillyId)!!
    val personBobby = database.personDao().getById(personBobbyId)!!
    val personBetty = database.personDao().getById(personBettyId)!!

    // relations class <=> persons
    database.relationClassPersonDao().insert(
        RelationClassPersonEntity(personBobby.id, classMiage.id),
        RelationClassPersonEntity(personBilly.id, classMiage.id),
        RelationClassPersonEntity(personBetty.id, classIrsi.id),
    )

    // subjects
    val (
        subjectAId,
        subjectBId
    ) = database.subjectDao().insert(
        SubjectEntity(
            name="Type A"
        ),
        SubjectEntity(
            name="Type B"
        )
    )

    val subjectA = database.subjectDao().getById(subjectAId)!!
    val subjectB = database.subjectDao().getById(subjectBId)!!

    // tasks
    val (
        taskA1Id,
        taskA2Id,
        taskA3Id,
        taskA4Id,
        taskA5Id,
    ) = database.taskDao().insert(
        // Subject A
        TaskEntity(
            title = "Installation Debian",
            description = "Installer la dernière version de Debian sur les Raspberry Pi.",
            order = 1,
            subjectId = subjectA.id,
        ),
        TaskEntity(
            title = "Connection de LEDs",
            description =
                "Utiliser les broches GPIO du Raspberry Pi pour brancher vos LEDs.\n" +
                "N'oublier pas les résistances !",
            order = 2,
            subjectId = subjectA.id,
        ),
        TaskEntity(
            title = "IDLE Python",
            description = "Installer l'éditeur basique Python avec 'apt install idle-python3.11'.",
            order = 3,
            subjectId = subjectA.id,
        ),
        TaskEntity(
            title = "Clignotement de LEDs",
            description = "Faite clignoter les différentes LEDs.",
            order = 4,
            subjectId = subjectA.id,
        ),
        TaskEntity(
            title = "Feu Tricolore",
            description = "Simuler un feu de circulation à l'aide de vos components.",
            order = 5,
            subjectId = subjectA.id,
        ),
    )

    val (
        taskB1Id,
        taskB2Id,
        taskB3Id,
        taskB4Id,
        taskB5Id,
    ) = database.taskDao().insert(
        // Subject B
        TaskEntity(
            title = "Préparation Arduino",
            description = "Préparer votre Arduino et assurer vous qu'il soit reconnu par votre ordinateur.",
            order = 1,
            subjectId = subjectB.id,
        ),
        TaskEntity(
            title = "Connection de LEDs",
            description =
            "Utiliser les broches de votre Arduino pour brancher vos LEDs.\n" +
                    "N'oublier pas les résistances !",
            order = 2,
            subjectId = subjectB.id,
        ),
        TaskEntity(
            title = "IDE Arduino",
            description = "Installer l'éditeur de code 'Arduino IDE'.",
            order = 3,
            subjectId = subjectB.id,
        ),
        TaskEntity(
            title = "Clignotement de LEDs",
            description = "Faite clignoter les différentes LEDs.",
            order = 4,
            subjectId = subjectB.id,
        ),
        TaskEntity(
            title = "Feu Tricolore",
            description = "Simuler un feu de circulation à l'aide de vos components.",
            order = 5,
            subjectId = subjectB.id,
        ),
    )

    val taskA1 = database.taskDao().getById(taskA1Id)!!
    val taskA2 = database.taskDao().getById(taskA2Id)!!
    val taskA3 = database.taskDao().getById(taskA3Id)!!
    val taskA4 = database.taskDao().getById(taskA4Id)!!
    val taskA5 = database.taskDao().getById(taskA5Id)!!

    val taskB1 = database.taskDao().getById(taskB1Id)!!
    val taskB2 = database.taskDao().getById(taskB2Id)!!
    val taskB3 = database.taskDao().getById(taskB3Id)!!
    val taskB4 = database.taskDao().getById(taskB4Id)!!
    val taskB5 = database.taskDao().getById(taskB5Id)!!
}


fun populateSubjectSessionPersonTest(database: TaskDatabase, session: SessionEntity) {
    // get the list of available subjects
    val subjects = database.subjectDao().getAll()

    // give a random subject to everyone in the session
    database.personDao().getAllBySession(session.id).forEach { person ->
        // get a random subject
        val subject = subjects.random()
        // insert a new subject for a person for a specific session
        database.relationPersonSessionSubjectDao().insert(
            RelationPersonSessionSubjectEntity(person.id, session.id, subject.id)
        )
    }
}