package com.faraphel.tasks_valider.ui.screen.communication.connection.wifiP2p.role

import android.app.Activity
import android.net.wifi.p2p.WifiP2pConfig
import android.net.wifi.p2p.WifiP2pDevice
import android.widget.Toast
import androidx.compose.foundation.layout.Column
import androidx.compose.runtime.*
import androidx.navigation.compose.NavHost
import androidx.navigation.compose.composable
import androidx.navigation.compose.rememberNavController
import com.faraphel.tasks_valider.connectivity.bwd.BwdManager
import com.faraphel.tasks_valider.connectivity.task.TaskClient
import com.faraphel.tasks_valider.connectivity.task.session.TaskSession
import com.faraphel.tasks_valider.ui.screen.communication.DEFAULT_SERVER_PORT
import com.faraphel.tasks_valider.ui.screen.communication.authentication.AuthenticationClientScreen
import com.faraphel.tasks_valider.ui.screen.communication.connection.internet.role.CommunicationInternetClientContent
import com.faraphel.tasks_valider.ui.screen.task.TaskSessionController
import com.faraphel.tasks_valider.ui.widgets.connectivity.WifiP2pDeviceListWidget


@Composable
fun CommunicationWifiP2pClientScreen(activity: Activity, bwdManager: BwdManager) {
    val controller = rememberNavController()

    val client = remember { mutableStateOf<TaskClient?>(null) }
    val session = remember { mutableStateOf<TaskSession?>(null) }

    NavHost(controller, startDestination = "communication") {
        composable("communication") {
            CommunicationWifiP2pClientContent(activity, client, bwdManager)
            if (client.value != null) controller.navigate("authentication")
        }
        composable("authentication") {
            AuthenticationClientScreen(activity, client.value!!, session)
            if (session.value != null) controller.navigate("session")
        }
        composable("session") {
            // show the main screen
            TaskSessionController(
                activity,
                client.value!!,
                session.value!!.person,
            )
        }
    }
}


@Composable
fun CommunicationWifiP2pClientContent(
    activity: Activity,
    client: MutableState<TaskClient?>,
    bwdManager: BwdManager,
) {
    val selectedDevice = remember { mutableStateOf<WifiP2pDevice?>(null) }

    // if the device is not selected
    if (selectedDevice.value == null) {
        Column {
            WifiP2pDeviceListWidget(
                peers = bwdManager.statePeers.value,
                filter = { device: WifiP2pDevice -> device.isGroupOwner },
                selectedDevice,
            )
        }

        LaunchedEffect(true) {
            // look for new peers
            bwdManager.discoverPeers()
        }

        return
    }

    val config = WifiP2pConfig().apply {
        deviceAddress = selectedDevice.value!!.deviceAddress
    }
    bwdManager.connect(config) {
        bwdManager.requestConnectionInfo { connectionInfo ->
            // if the group has not been formed correctly, the host did not approve the connection
            if (!connectionInfo.groupFormed) {
                selectedDevice.value = null
                Toast.makeText(activity, "Require host approval.", Toast.LENGTH_LONG).show()
                return@requestConnectionInfo
            }

            // create a connection to the server
            // TODO(Faraphel): check if the server is reachable
            client.value = TaskClient(
                connectionInfo.groupOwnerAddress.hostAddress!!,
                DEFAULT_SERVER_PORT
            )
        }
    }

}