package com.faraphel.tasks_valider.ui.widgets.connectivity

import android.net.wifi.p2p.WifiP2pDevice
import android.net.wifi.p2p.WifiP2pDeviceList
import androidx.compose.foundation.layout.*
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.MutableState
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp


/**
 * Represent a list of WiFi-Direct devices.
 * @param peers the list of peers to represent
 * @param filter a filter for the peers
 * @param deviceState a state containing the selected device
 */
@Composable
fun WifiP2pDeviceListWidget(
    peers: WifiP2pDeviceList?,
    filter: ((WifiP2pDevice) -> Boolean)? = null,
    deviceState: MutableState<WifiP2pDevice?>? = null,
) {
    Column(
        modifier = Modifier.fillMaxSize(),
        horizontalAlignment = Alignment.CenterHorizontally
    ) {
        // title
        Text(
            text = "Devices",
            fontSize = 32.sp,
        )
        // found device count
        Text(
            text = "(${peers?.deviceList?.size ?: 0})",
            fontSize = 24.sp,
        )

        // separator
        Spacer(modifier = Modifier.height(24.dp))

        // if there are peers to display
        if (peers != null) {
            // for every device in the list
            for (device in peers.deviceList) {
                // if the filter (if set) does not apply to this device, ignore it
                if (filter != null && !filter(device))
                    continue

                // create a new object for the device
                WifiP2pDeviceWidget(device, deviceState)
            }
        }
    }
}